Crate elefant_client

Crate elefant_client 

Re-exports

pub use batch::CollectBatch;
pub use batch::FlattenTuple;
pub use batch::TupleAppend;
pub use pool::ConnectionFactory;
pub use pool::PoolableClient;
pub use pool::PostgresPool;

Modules

batch
pool
profiler
replication

Macros

impl_from_sql_for_domain_type
reborrow_until_polonius

Structs

CopyReader
CopyWriter
EnumOidEntry
Registration data for an enum type, used when inserting into the registry.
EnumTypeRegistry
Runtime registry mapping PostgreSQL enum OIDs to their type names.
FieldDescription
Inet
PostgreSQL INET type representing IP addresses with optional subnet mask
Oid
OwnedCopyReader
Point
PostgreSQL POINT geometric type representing x,y coordinates
PostgresClient
PostgresConnectionSettings
PostgresDataRow
PostgresType
PreparedQuery
QueryResult
RowResultReader
SimpleQueryResult

Enums

ElefantClientError
QueryResultSet

Traits

DomainType
FromSql
Compatibility trait that provides both binary and text format support This maintains backward compatibility with existing code
FromSqlBase
Base trait providing shared functionality for both binary and text format trait implementations
FromSqlBinary
Trait for types that can be deserialized from PostgreSQL binary format data
FromSqlBinaryOwned
A trait for types which can be created from binary Postgres values without borrowing any data.
FromSqlOwned
A trait for types which can be created from a Postgres value without borrowing any data. This is primarily useful for trait bounds on functions.
FromSqlRow
FromSqlRowOwned
FromSqlText
Trait for types that can be deserialized from PostgreSQL text format data
FromSqlTextOwned
A trait for types which can be created from text Postgres values without borrowing any data.
PostgresEnum
Trait implemented by Rust enums that map to PostgreSQL enum types.
PostgresNamedType
Statement
ToSql

Type Aliases

Cidr