PoolableClient

Struct PoolableClient 

pub struct PoolableClient<F: ConnectionFactory> { /* private fields */ }

Implementations

Source

impl<F: ConnectionFactory> PoolableClient<F>

pub async fn close(self) -> Result<(), ElefantClientError>

Gracefully close this connection by sending Terminate to the backend. The connection is not returned to the pool. Consumes the client.

Methods from Deref<Target = PostgresClient<F>>

pub async fn copy_out( &mut self, query: &(impl Statement + ?Sized), parameters: &[&dyn ToSql], ) -> Result<CopyReader<'_, F>, ElefantClientError>

pub async fn copy_in( &mut self, query: &(impl Statement + ?Sized), parameters: &[&dyn ToSql], ) -> Result<CopyWriter<'_, F>, ElefantClientError>

pub async fn execute_non_query<S>( &mut self, query: &S, parameters: &[&dyn ToSql], ) -> Result<(), ElefantClientError>
where S: Statement + ?Sized,

Execute a non-query statement using binary mode (with prepared statements)

pub async fn execute_non_query_simple( &mut self, query: &str, ) -> Result<(), ElefantClientError>

Execute a non-query statement using simple query mode (text format, no parameters)

pub async fn query( &mut self, query: &(impl Statement + ?Sized), parameters: &[&dyn ToSql], ) -> Result<QueryResult<'_, F>, ElefantClientError>

Execute a query in binary mode - always uses prepared statements

pub async fn query_simple( &mut self, query: &str, ) -> Result<SimpleQueryResult<'_, F>, ElefantClientError>

Execute a simple query in text mode - only accepts &str, no parameters

pub async fn prepare_query( &mut self, query: &str, ) -> Result<PreparedQuery, ElefantClientError>

pub async fn create_replication_slot( &mut self, slot_name: &str, output_plugin: &str, ) -> Result<(String, Lsn), ElefantClientError>

pub async fn drop_replication_slot( &mut self, slot_name: &str, ) -> Result<(), ElefantClientError>

pub async fn start_replication( &mut self, slot_name: &str, lsn: Lsn, options: &str, ) -> Result<ReplicationStream<'_, F>, ElefantClientError>

pub async fn reset(&mut self) -> Result<(), ElefantClientError>

pub fn get_parameter(&self, name: &str) -> Option<&str>

Get a server parameter received via ParameterStatus messages.

PostgreSQL sends these during connection startup and whenever a session parameter changes. Common parameters include server_version, server_encoding, TimeZone, etc.