Re-exports
pub use batch::CollectBatch;pub use batch::FlattenTuple;pub use batch::TupleAppend;pub use pool::ConnectionFactory;pub use pool::PoolableClient;pub use pool::PostgresPool;
Modules
Macros
Structs
- Copy
Reader - Copy
Writer - Enum
OidEntry - Registration data for an enum type, used when inserting into the registry.
- Enum
Type Registry - Runtime registry mapping PostgreSQL enum OIDs to their type names.
- Field
Description - Inet
- PostgreSQL INET type representing IP addresses with optional subnet mask
- Oid
- Owned
Copy Reader - Point
- PostgreSQL POINT geometric type representing x,y coordinates
- Postgres
Client - Postgres
Connection Settings - Postgres
Data Row - Postgres
Type - Prepared
Query - Query
Result - RowResult
Reader - Simple
Query Result
Enums
Traits
- Domain
Type - FromSql
- Compatibility trait that provides both binary and text format support This maintains backward compatibility with existing code
- From
SqlBase - Base trait providing shared functionality for both binary and text format trait implementations
- From
SqlBinary - Trait for types that can be deserialized from PostgreSQL binary format data
- From
SqlBinary Owned - A trait for types which can be created from binary Postgres values without borrowing any data.
- From
SqlOwned - A trait for types which can be created from a Postgres value without borrowing any data. This is primarily useful for trait bounds on functions.
- From
SqlRow - From
SqlRow Owned - From
SqlText - Trait for types that can be deserialized from PostgreSQL text format data
- From
SqlText Owned - A trait for types which can be created from text Postgres values without borrowing any data.
- Postgres
Enum - Trait implemented by Rust enums that map to PostgreSQL enum types.
- Postgres
Named Type - Statement
- ToSql