pub struct PostgresPool<F: ConnectionFactory>(/* private fields */);Implementations
Sourceimpl<F: ConnectionFactory> PostgresPool<F>
impl<F: ConnectionFactory> PostgresPool<F>
pub async fn new( factory: F, settings: PostgresConnectionSettings, ) -> Result<Self, ElefantClientError>
pub fn settings(&self) -> &PostgresConnectionSettings
pub fn enum_registry(&self) -> &Arc<EnumTypeRegistry> ⓘ
Sourcepub async fn close(&self) -> Result<(), ElefantClientError>
pub async fn close(&self) -> Result<(), ElefantClientError>
Gracefully close all idle connections by sending Terminate to each.
Currently checked-out clients are not affected — close them individually
via PoolableClient::close or let them return to the pool first.
pub async fn get_client(&self) -> Result<PoolableClient<F>, ElefantClientError>